Stan Math Library: stan/math/prim/scal/fun/logical_neq.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

logical_neq.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_PRIM_SCAL_FUN_LOGICAL_NEQ_HPP
2 #define STAN_MATH_PRIM_SCAL_FUN_LOGICAL_NEQ_HPP
3
4 namespace stan {
5 namespace math {
6
17 template <typename T1, typename T2>
18 inline int
19 logical_neq(const T1 x1, const T2 x2) {
20 return x1 != x2;
21 }
22
23 }
24 }
25 #endif
stan
Definition: log_sum_exp.hpp:8
stan::math::logical_neq
int logical_neq(const T1 x1, const T2 x2)
Return 1 if the first argument is unequal to the second.
Definition: logical_neq.hpp:19

[ Stan Home Page ] © 2011–2016, Stan Development Team.